Class: CloudmersiveDlpApiClient::DlpDocumentDetectionRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb

Overview

Request object for DLP document detection with 23 PII detection types.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DlpDocumentDetectionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'InputFile')
    self.input_file = attributes[:'InputFile']
  end

  if attributes.has_key?(:'FileName')
    self.file_name = attributes[:'FileName']
  end

  if attributes.has_key?(:'RecognitionMode')
    self.recognition_mode = attributes[:'RecognitionMode']
  end

  if attributes.has_key?(:'AllowEmailAddress')
    self.allow_email_address = attributes[:'AllowEmailAddress']
  end

  if attributes.has_key?(:'AllowPhoneNumber')
    self.allow_phone_number = attributes[:'AllowPhoneNumber']
  end

  if attributes.has_key?(:'AllowStreetAddress')
    self.allow_street_address = attributes[:'AllowStreetAddress']
  end

  if attributes.has_key?(:'AllowPersonName')
    self.allow_person_name = attributes[:'AllowPersonName']
  end

  if attributes.has_key?(:'AllowBirthDate')
    self.allow_birth_date = attributes[:'AllowBirthDate']
  end

  if attributes.has_key?(:'AllowPassportNumber')
    self.allow_passport_number = attributes[:'AllowPassportNumber']
  end

  if attributes.has_key?(:'AllowDriversLicense')
    self.allow_drivers_license = attributes[:'AllowDriversLicense']
  end

  if attributes.has_key?(:'AllowSocialSecurityNumber')
    self.allow_social_security_number = attributes[:'AllowSocialSecurityNumber']
  end

  if attributes.has_key?(:'AllowTaxpayerID')
    self.allow_taxpayer_id = attributes[:'AllowTaxpayerID']
  end

  if attributes.has_key?(:'AllowCreditCardNumber')
    self.allow_credit_card_number = attributes[:'AllowCreditCardNumber']
  end

  if attributes.has_key?(:'AllowCreditCardExpirationDate')
    self.allow_credit_card_expiration_date = attributes[:'AllowCreditCardExpirationDate']
  end

  if attributes.has_key?(:'AllowCreditCardVerificationCode')
    self.allow_credit_card_verification_code = attributes[:'AllowCreditCardVerificationCode']
  end

  if attributes.has_key?(:'AllowBankAccountNumber')
    self. = attributes[:'AllowBankAccountNumber']
  end

  if attributes.has_key?(:'AllowIBAN')
    self.allow_iban = attributes[:'AllowIBAN']
  end

  if attributes.has_key?(:'AllowHealthInsuranceNumber')
    self.allow_health_insurance_number = attributes[:'AllowHealthInsuranceNumber']
  end

  if attributes.has_key?(:'AllowBearerToken')
    self.allow_bearer_token = attributes[:'AllowBearerToken']
  end

  if attributes.has_key?(:'AllowHttpCookie')
    self.allow_http_cookie = attributes[:'AllowHttpCookie']
  end

  if attributes.has_key?(:'AllowPrivateKeys')
    self.allow_private_keys = attributes[:'AllowPrivateKeys']
  end

  if attributes.has_key?(:'AllowCredentials')
    self.allow_credentials = attributes[:'AllowCredentials']
  end

  if attributes.has_key?(:'AllowDeepWebUrls')
    self.allow_deep_web_urls = attributes[:'AllowDeepWebUrls']
  end

  if attributes.has_key?(:'AllowSourceCode')
    self.allow_source_code = attributes[:'AllowSourceCode']
  end

  if attributes.has_key?(:'AllowIpAddress')
    self.allow_ip_address = attributes[:'AllowIpAddress']
  end

  if attributes.has_key?(:'AllowMacAddress')
    self.allow_mac_address = attributes[:'AllowMacAddress']
  end
end

Instance Attribute Details

#allow_bank_account_numberObject

Set to true to allow bank account numbers in the document and not flag them as PII.



64
65
66
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 64

def 
  @allow_bank_account_number
end

#allow_bearer_tokenObject

Set to true to allow bearer tokens in the document and not flag them as PII.



73
74
75
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 73

def allow_bearer_token
  @allow_bearer_token
end

#allow_birth_dateObject

Set to true to allow birth dates in the document and not flag them as PII.



40
41
42
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 40

def allow_birth_date
  @allow_birth_date
end

#allow_credentialsObject

Set to true to allow credentials (usernames/passwords) in the document and not flag them as PII.



82
83
84
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 82

def allow_credentials
  @allow_credentials
end

#allow_credit_card_expiration_dateObject

Set to true to allow credit card expiration dates in the document and not flag them as PII.



58
59
60
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 58

def allow_credit_card_expiration_date
  @allow_credit_card_expiration_date
end

#allow_credit_card_numberObject

Set to true to allow credit card numbers in the document and not flag them as PII.



55
56
57
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 55

def allow_credit_card_number
  @allow_credit_card_number
end

#allow_credit_card_verification_codeObject

Set to true to allow credit card verification codes in the document and not flag them as PII.



61
62
63
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 61

def allow_credit_card_verification_code
  @allow_credit_card_verification_code
end

#allow_deep_web_urlsObject

Set to true to allow deep web URLs (.onion) in the document and not flag them as PII.



85
86
87
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 85

def allow_deep_web_urls
  @allow_deep_web_urls
end

#allow_drivers_licenseObject

Set to true to allow drivers license numbers in the document and not flag them as PII.



46
47
48
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 46

def allow_drivers_license
  @allow_drivers_license
end

#allow_email_addressObject

Set to true to allow email addresses in the document and not flag them as PII.



28
29
30
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 28

def allow_email_address
  @allow_email_address
end

#allow_health_insurance_numberObject

Set to true to allow health insurance numbers in the document and not flag them as PII.



70
71
72
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 70

def allow_health_insurance_number
  @allow_health_insurance_number
end

Set to true to allow HTTP cookies in the document and not flag them as PII.



76
77
78
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 76

def allow_http_cookie
  @allow_http_cookie
end

#allow_ibanObject

Set to true to allow IBANs in the document and not flag them as PII.



67
68
69
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 67

def allow_iban
  @allow_iban
end

#allow_ip_addressObject

Set to true to allow IP addresses in the document and not flag them as PII.



91
92
93
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 91

def allow_ip_address
  @allow_ip_address
end

#allow_mac_addressObject

Set to true to allow MAC addresses in the document and not flag them as PII.



94
95
96
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 94

def allow_mac_address
  @allow_mac_address
end

#allow_passport_numberObject

Set to true to allow passport numbers in the document and not flag them as PII.



43
44
45
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 43

def allow_passport_number
  @allow_passport_number
end

#allow_person_nameObject

Set to true to allow person names in the document and not flag them as PII.



37
38
39
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 37

def allow_person_name
  @allow_person_name
end

#allow_phone_numberObject

Set to true to allow phone numbers in the document and not flag them as PII.



31
32
33
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 31

def allow_phone_number
  @allow_phone_number
end

#allow_private_keysObject

Set to true to allow private keys in the document and not flag them as PII.



79
80
81
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 79

def allow_private_keys
  @allow_private_keys
end

#allow_social_security_numberObject

Set to true to allow social security numbers in the document and not flag them as PII.



49
50
51
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 49

def allow_social_security_number
  @allow_social_security_number
end

#allow_source_codeObject

Set to true to allow source code in the document and not flag it as sensitive data.



88
89
90
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 88

def allow_source_code
  @allow_source_code
end

#allow_street_addressObject

Set to true to allow street addresses in the document and not flag them as PII.



34
35
36
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 34

def allow_street_address
  @allow_street_address
end

#allow_taxpayer_idObject

Set to true to allow taxpayer IDs in the document and not flag them as PII.



52
53
54
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 52

def allow_taxpayer_id
  @allow_taxpayer_id
end

#file_nameObject

Optional. Name of the input file including extension, used for format detection. If not provided, format is detected from file contents.



22
23
24
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 22

def file_name
  @file_name
end

#input_fileObject

Document file bytes (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, or WEBP) to scan for PII and sensitive data.



19
20
21
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 19

def input_file
  @input_file
end

#recognition_modeObject

Optional. Recognition mode for image processing. Options: null (default), "Normal", "Advanced", "Fast", "FastPlus", "FastMini".



25
26
27
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 25

def recognition_mode
  @recognition_mode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 97

def self.attribute_map
  {
    :'input_file' => :'InputFile',
    :'file_name' => :'FileName',
    :'recognition_mode' => :'RecognitionMode',
    :'allow_email_address' => :'AllowEmailAddress',
    :'allow_phone_number' => :'AllowPhoneNumber',
    :'allow_street_address' => :'AllowStreetAddress',
    :'allow_person_name' => :'AllowPersonName',
    :'allow_birth_date' => :'AllowBirthDate',
    :'allow_passport_number' => :'AllowPassportNumber',
    :'allow_drivers_license' => :'AllowDriversLicense',
    :'allow_social_security_number' => :'AllowSocialSecurityNumber',
    :'allow_taxpayer_id' => :'AllowTaxpayerID',
    :'allow_credit_card_number' => :'AllowCreditCardNumber',
    :'allow_credit_card_expiration_date' => :'AllowCreditCardExpirationDate',
    :'allow_credit_card_verification_code' => :'AllowCreditCardVerificationCode',
    :'allow_bank_account_number' => :'AllowBankAccountNumber',
    :'allow_iban' => :'AllowIBAN',
    :'allow_health_insurance_number' => :'AllowHealthInsuranceNumber',
    :'allow_bearer_token' => :'AllowBearerToken',
    :'allow_http_cookie' => :'AllowHttpCookie',
    :'allow_private_keys' => :'AllowPrivateKeys',
    :'allow_credentials' => :'AllowCredentials',
    :'allow_deep_web_urls' => :'AllowDeepWebUrls',
    :'allow_source_code' => :'AllowSourceCode',
    :'allow_ip_address' => :'AllowIpAddress',
    :'allow_mac_address' => :'AllowMacAddress'
  }
end

.swagger_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 129

def self.swagger_types
  {
    :'input_file' => :'String',
    :'file_name' => :'String',
    :'recognition_mode' => :'String',
    :'allow_email_address' => :'BOOLEAN',
    :'allow_phone_number' => :'BOOLEAN',
    :'allow_street_address' => :'BOOLEAN',
    :'allow_person_name' => :'BOOLEAN',
    :'allow_birth_date' => :'BOOLEAN',
    :'allow_passport_number' => :'BOOLEAN',
    :'allow_drivers_license' => :'BOOLEAN',
    :'allow_social_security_number' => :'BOOLEAN',
    :'allow_taxpayer_id' => :'BOOLEAN',
    :'allow_credit_card_number' => :'BOOLEAN',
    :'allow_credit_card_expiration_date' => :'BOOLEAN',
    :'allow_credit_card_verification_code' => :'BOOLEAN',
    :'allow_bank_account_number' => :'BOOLEAN',
    :'allow_iban' => :'BOOLEAN',
    :'allow_health_insurance_number' => :'BOOLEAN',
    :'allow_bearer_token' => :'BOOLEAN',
    :'allow_http_cookie' => :'BOOLEAN',
    :'allow_private_keys' => :'BOOLEAN',
    :'allow_credentials' => :'BOOLEAN',
    :'allow_deep_web_urls' => :'BOOLEAN',
    :'allow_source_code' => :'BOOLEAN',
    :'allow_ip_address' => :'BOOLEAN',
    :'allow_mac_address' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 303

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      input_file == o.input_file &&
      file_name == o.file_name &&
      recognition_mode == o.recognition_mode &&
      allow_email_address == o.allow_email_address &&
      allow_phone_number == o.allow_phone_number &&
      allow_street_address == o.allow_street_address &&
      allow_person_name == o.allow_person_name &&
      allow_birth_date == o.allow_birth_date &&
      allow_passport_number == o.allow_passport_number &&
      allow_drivers_license == o.allow_drivers_license &&
      allow_social_security_number == o.allow_social_security_number &&
      allow_taxpayer_id == o.allow_taxpayer_id &&
      allow_credit_card_number == o.allow_credit_card_number &&
      allow_credit_card_expiration_date == o.allow_credit_card_expiration_date &&
      allow_credit_card_verification_code == o.allow_credit_card_verification_code &&
       == o. &&
      allow_iban == o.allow_iban &&
      allow_health_insurance_number == o.allow_health_insurance_number &&
      allow_bearer_token == o.allow_bearer_token &&
      allow_http_cookie == o.allow_http_cookie &&
      allow_private_keys == o.allow_private_keys &&
      allow_credentials == o.allow_credentials &&
      allow_deep_web_urls == o.allow_deep_web_urls &&
      allow_source_code == o.allow_source_code &&
      allow_ip_address == o.allow_ip_address &&
      allow_mac_address == o.allow_mac_address
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 370

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudmersiveDlpApiClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 436

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 349

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


336
337
338
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 336

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



342
343
344
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 342

def hash
  [input_file, file_name, recognition_mode, allow_email_address, allow_phone_number, allow_street_address, allow_person_name, allow_birth_date, allow_passport_number, allow_drivers_license, allow_social_security_number, allow_taxpayer_id, allow_credit_card_number, allow_credit_card_expiration_date, allow_credit_card_verification_code, , allow_iban, allow_health_insurance_number, allow_bearer_token, allow_http_cookie, allow_private_keys, allow_credentials, allow_deep_web_urls, allow_source_code, allow_ip_address, allow_mac_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



275
276
277
278
279
280
281
282
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 275

def list_invalid_properties
  invalid_properties = Array.new
  if !@input_file.nil? && @input_file !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/)
    invalid_properties.push('invalid value for "input_file", must conform to the pattern /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



416
417
418
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 416

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



422
423
424
425
426
427
428
429
430
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 422

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



410
411
412
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 410

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



286
287
288
289
# File 'lib/cloudmersive-dlp-api-client/models/dlp_document_detection_request.rb', line 286

def valid?
  return false if !@input_file.nil? && @input_file !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/)
  true
end