Class: CloudmersiveDlpApiClient::RedactApi
- Inherits:
-
Object
- Object
- CloudmersiveDlpApiClient::RedactApi
- Defined in:
- lib/cloudmersive-dlp-api-client/api/redact_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RedactApi
constructor
A new instance of RedactApi.
-
#redact_audio(opts = {}) ⇒ DlpAudioRedactionResponse
Redact User Data in Audio File Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII.
-
#redact_audio_advanced(opts = {}) ⇒ DlpAdvancedAudioRedactionResponse
Redact User Data in Audio File (Advanced) Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII.
-
#redact_audio_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedAudioRedactionResponse, Fixnum, Hash)>
Redact User Data in Audio File (Advanced) Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII.
-
#redact_audio_with_http_info(opts = {}) ⇒ Array<(DlpAudioRedactionResponse, Fixnum, Hash)>
Redact User Data in Audio File Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII.
-
#redact_document(opts = {}) ⇒ DlpDocumentRedactionResponse
Redact User Data in Document Detects and redacts configurable types of user data in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI.
-
#redact_document_advanced(opts = {}) ⇒ DlpAdvancedDocumentRedactionResponse
Redact User Data in Document (Advanced) Detects and redacts 35 configurable types of user data including health-related PHI in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI.
-
#redact_document_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedDocumentRedactionResponse, Fixnum, Hash)>
Redact User Data in Document (Advanced) Detects and redacts 35 configurable types of user data including health-related PHI in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI.
-
#redact_document_with_http_info(opts = {}) ⇒ Array<(DlpDocumentRedactionResponse, Fixnum, Hash)>
Redact User Data in Document Detects and redacts configurable types of user data in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI.
-
#redact_text(opts = {}) ⇒ DlpRedactionResponse
Redact User Data in Input Text Detects and redacts configurable types of user data in an input text string using Advanced AI.
-
#redact_text_advanced(opts = {}) ⇒ DlpAdvancedRedactionResponse
Redact User Data in Input Text (Advanced) Detects and redacts 34 configurable types of user data including health-related PHI in an input text string using Advanced AI.
-
#redact_text_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedRedactionResponse, Fixnum, Hash)>
Redact User Data in Input Text (Advanced) Detects and redacts 34 configurable types of user data including health-related PHI in an input text string using Advanced AI.
-
#redact_text_with_http_info(opts = {}) ⇒ Array<(DlpRedactionResponse, Fixnum, Hash)>
Redact User Data in Input Text Detects and redacts configurable types of user data in an input text string using Advanced AI.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#redact_audio(opts = {}) ⇒ DlpAudioRedactionResponse
Redact User Data in Audio File Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, and redacted segment timestamps.
27 28 29 30 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 27 def redact_audio(opts = {}) data, _status_code, _headers = redact_audio_with_http_info(opts) data end |
#redact_audio_advanced(opts = {}) ⇒ DlpAdvancedAudioRedactionResponse
Redact User Data in Audio File (Advanced) Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, redacted segment timestamps, and optional rationale.
77 78 79 80 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 77 def redact_audio_advanced(opts = {}) data, _status_code, _headers = redact_audio_advanced_with_http_info(opts) data end |
#redact_audio_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedAudioRedactionResponse, Fixnum, Hash)>
Redact User Data in Audio File (Advanced) Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, redacted segment timestamps, and optional rationale.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 87 def redact_audio_advanced_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_audio_advanced ...' end # resource path local_var_path = '/dlp/redact/audio/advanced' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpAdvancedAudioRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_audio_advanced\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_audio_with_http_info(opts = {}) ⇒ Array<(DlpAudioRedactionResponse, Fixnum, Hash)>
Redact User Data in Audio File Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, and redacted segment timestamps.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 37 def redact_audio_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_audio ...' end # resource path local_var_path = '/dlp/redact/audio' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpAudioRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_audio\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_document(opts = {}) ⇒ DlpDocumentRedactionResponse
Redact User Data in Document Detects and redacts configurable types of user data in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI. Rasterizes document pages, detects PII regions using a grid-overlay approach, blurs those regions, and returns a rasterized PDF.
127 128 129 130 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 127 def redact_document(opts = {}) data, _status_code, _headers = redact_document_with_http_info(opts) data end |
#redact_document_advanced(opts = {}) ⇒ DlpAdvancedDocumentRedactionResponse
Redact User Data in Document (Advanced) Detects and redacts 35 configurable types of user data including health-related PHI in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI. Rasterizes document pages, detects PII regions using a row-overlay approach, redacts those regions, and returns a rasterized PDF.
177 178 179 180 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 177 def redact_document_advanced(opts = {}) data, _status_code, _headers = redact_document_advanced_with_http_info(opts) data end |
#redact_document_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedDocumentRedactionResponse, Fixnum, Hash)>
Redact User Data in Document (Advanced) Detects and redacts 35 configurable types of user data including health-related PHI in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI. Rasterizes document pages, detects PII regions using a row-overlay approach, redacts those regions, and returns a rasterized PDF.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 187 def redact_document_advanced_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_document_advanced ...' end # resource path local_var_path = '/dlp/redact/document/advanced' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpAdvancedDocumentRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_document_advanced\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_document_with_http_info(opts = {}) ⇒ Array<(DlpDocumentRedactionResponse, Fixnum, Hash)>
Redact User Data in Document Detects and redacts configurable types of user data in a document (PDF, DOC, DOCX, XLS, XLSX, PPT, PPTX, HTML, EML, MSG, PNG, JPG, WEBP) using Advanced AI. Rasterizes document pages, detects PII regions using a grid-overlay approach, blurs those regions, and returns a rasterized PDF.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 137 def redact_document_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_document ...' end # resource path local_var_path = '/dlp/redact/document' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpDocumentRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_text(opts = {}) ⇒ DlpRedactionResponse
Redact User Data in Input Text Detects and redacts configurable types of user data in an input text string using Advanced AI. First detects PII, then redacts disallowed types by either deleting them or replacing them with asterisks.
227 228 229 230 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 227 def redact_text(opts = {}) data, _status_code, _headers = redact_text_with_http_info(opts) data end |
#redact_text_advanced(opts = {}) ⇒ DlpAdvancedRedactionResponse
Redact User Data in Input Text (Advanced) Detects and redacts 34 configurable types of user data including health-related PHI in an input text string using Advanced AI. First detects PII, then redacts disallowed types by either deleting them or replacing them with asterisks.
277 278 279 280 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 277 def redact_text_advanced(opts = {}) data, _status_code, _headers = redact_text_advanced_with_http_info(opts) data end |
#redact_text_advanced_with_http_info(opts = {}) ⇒ Array<(DlpAdvancedRedactionResponse, Fixnum, Hash)>
Redact User Data in Input Text (Advanced) Detects and redacts 34 configurable types of user data including health-related PHI in an input text string using Advanced AI. First detects PII, then redacts disallowed types by either deleting them or replacing them with asterisks.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 287 def redact_text_advanced_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_text_advanced ...' end # resource path local_var_path = '/dlp/redact/text/advanced' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpAdvancedRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_text_advanced\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_text_with_http_info(opts = {}) ⇒ Array<(DlpRedactionResponse, Fixnum, Hash)>
Redact User Data in Input Text Detects and redacts configurable types of user data in an input text string using Advanced AI. First detects PII, then redacts disallowed types by either deleting them or replacing them with asterisks.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/cloudmersive-dlp-api-client/api/redact_api.rb', line 237 def redact_text_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RedactApi.redact_text ...' end # resource path local_var_path = '/dlp/redact/text' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpRedactionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: RedactApi#redact_text\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |