Class: CloudmersiveDlpApiClient::DlpDetectionRequest
- Inherits:
-
Object
- Object
- CloudmersiveDlpApiClient::DlpDetectionRequest
- Defined in:
- lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb
Overview
Request object for DLP text detection with 23 PII detection types.
Instance Attribute Summary collapse
-
#allow_bank_account_number ⇒ Object
Set to true to allow bank account numbers in the input text and not flag them as PII.
-
#allow_bearer_token ⇒ Object
Set to true to allow bearer tokens in the input text and not flag them as PII.
-
#allow_birth_date ⇒ Object
Set to true to allow birth dates in the input text and not flag them as PII.
-
#allow_credentials ⇒ Object
Set to true to allow credentials (usernames/passwords) in the input text and not flag them as PII.
-
#allow_credit_card_expiration_date ⇒ Object
Set to true to allow credit card expiration dates in the input text and not flag them as PII.
-
#allow_credit_card_number ⇒ Object
Set to true to allow credit card numbers in the input text and not flag them as PII.
-
#allow_credit_card_verification_code ⇒ Object
Set to true to allow credit card verification codes in the input text and not flag them as PII.
-
#allow_deep_web_urls ⇒ Object
Set to true to allow deep web URLs (.onion) in the input text and not flag them as PII.
-
#allow_drivers_license ⇒ Object
Set to true to allow drivers license numbers in the input text and not flag them as PII.
-
#allow_email_address ⇒ Object
Set to true to allow email addresses in the input text and not flag them as PII.
-
#allow_health_insurance_number ⇒ Object
Set to true to allow health insurance numbers in the input text and not flag them as PII.
-
#allow_http_cookie ⇒ Object
Set to true to allow HTTP cookies in the input text and not flag them as PII.
-
#allow_iban ⇒ Object
Set to true to allow IBANs in the input text and not flag them as PII.
-
#allow_ip_address ⇒ Object
Set to true to allow IP addresses in the input text and not flag them as PII.
-
#allow_mac_address ⇒ Object
Set to true to allow MAC addresses in the input text and not flag them as PII.
-
#allow_passport_number ⇒ Object
Set to true to allow passport numbers in the input text and not flag them as PII.
-
#allow_person_name ⇒ Object
Set to true to allow person names in the input text and not flag them as PII.
-
#allow_phone_number ⇒ Object
Set to true to allow phone numbers in the input text and not flag them as PII.
-
#allow_private_keys ⇒ Object
Set to true to allow private keys in the input text and not flag them as PII.
-
#allow_social_security_number ⇒ Object
Set to true to allow social security numbers in the input text and not flag them as PII.
-
#allow_source_code ⇒ Object
Set to true to allow source code in the input text and not flag it as sensitive data.
-
#allow_street_address ⇒ Object
Set to true to allow street addresses in the input text and not flag them as PII.
-
#allow_taxpayer_id ⇒ Object
Set to true to allow taxpayer IDs in the input text and not flag them as PII.
-
#input_text ⇒ Object
Text to scan for PII and sensitive data.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DlpDetectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DlpDetectionRequest
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 152 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'InputText') self.input_text = attributes[:'InputText'] end if attributes.has_key?(:'AllowEmailAddress') self.allow_email_address = attributes[:'AllowEmailAddress'] end if attributes.has_key?(:'AllowPhoneNumber') self.allow_phone_number = attributes[:'AllowPhoneNumber'] end if attributes.has_key?(:'AllowStreetAddress') self.allow_street_address = attributes[:'AllowStreetAddress'] end if attributes.has_key?(:'AllowPersonName') self.allow_person_name = attributes[:'AllowPersonName'] end if attributes.has_key?(:'AllowBirthDate') self.allow_birth_date = attributes[:'AllowBirthDate'] end if attributes.has_key?(:'AllowPassportNumber') self.allow_passport_number = attributes[:'AllowPassportNumber'] end if attributes.has_key?(:'AllowDriversLicense') self.allow_drivers_license = attributes[:'AllowDriversLicense'] end if attributes.has_key?(:'AllowSocialSecurityNumber') self. = attributes[:'AllowSocialSecurityNumber'] end if attributes.has_key?(:'AllowTaxpayerID') self.allow_taxpayer_id = attributes[:'AllowTaxpayerID'] end if attributes.has_key?(:'AllowCreditCardNumber') self.allow_credit_card_number = attributes[:'AllowCreditCardNumber'] end if attributes.has_key?(:'AllowCreditCardExpirationDate') self.allow_credit_card_expiration_date = attributes[:'AllowCreditCardExpirationDate'] end if attributes.has_key?(:'AllowCreditCardVerificationCode') self.allow_credit_card_verification_code = attributes[:'AllowCreditCardVerificationCode'] end if attributes.has_key?(:'AllowBankAccountNumber') self.allow_bank_account_number = attributes[:'AllowBankAccountNumber'] end if attributes.has_key?(:'AllowIBAN') self.allow_iban = attributes[:'AllowIBAN'] end if attributes.has_key?(:'AllowHealthInsuranceNumber') self.allow_health_insurance_number = attributes[:'AllowHealthInsuranceNumber'] end if attributes.has_key?(:'AllowBearerToken') self.allow_bearer_token = attributes[:'AllowBearerToken'] end if attributes.has_key?(:'AllowHttpCookie') self. = attributes[:'AllowHttpCookie'] end if attributes.has_key?(:'AllowPrivateKeys') self.allow_private_keys = attributes[:'AllowPrivateKeys'] end if attributes.has_key?(:'AllowCredentials') self.allow_credentials = attributes[:'AllowCredentials'] end if attributes.has_key?(:'AllowDeepWebUrls') self.allow_deep_web_urls = attributes[:'AllowDeepWebUrls'] end if attributes.has_key?(:'AllowSourceCode') self.allow_source_code = attributes[:'AllowSourceCode'] end if attributes.has_key?(:'AllowIpAddress') self.allow_ip_address = attributes[:'AllowIpAddress'] end if attributes.has_key?(:'AllowMacAddress') self.allow_mac_address = attributes[:'AllowMacAddress'] end end |
Instance Attribute Details
#allow_bank_account_number ⇒ Object
Set to true to allow bank account numbers in the input text and not flag them as PII.
58 59 60 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 58 def allow_bank_account_number @allow_bank_account_number end |
#allow_bearer_token ⇒ Object
Set to true to allow bearer tokens in the input text and not flag them as PII.
67 68 69 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 67 def allow_bearer_token @allow_bearer_token end |
#allow_birth_date ⇒ Object
Set to true to allow birth dates in the input text and not flag them as PII.
34 35 36 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 34 def allow_birth_date @allow_birth_date end |
#allow_credentials ⇒ Object
Set to true to allow credentials (usernames/passwords) in the input text and not flag them as PII.
76 77 78 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 76 def allow_credentials @allow_credentials end |
#allow_credit_card_expiration_date ⇒ Object
Set to true to allow credit card expiration dates in the input text and not flag them as PII.
52 53 54 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 52 def allow_credit_card_expiration_date @allow_credit_card_expiration_date end |
#allow_credit_card_number ⇒ Object
Set to true to allow credit card numbers in the input text and not flag them as PII.
49 50 51 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 49 def allow_credit_card_number @allow_credit_card_number end |
#allow_credit_card_verification_code ⇒ Object
Set to true to allow credit card verification codes in the input text and not flag them as PII.
55 56 57 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 55 def allow_credit_card_verification_code @allow_credit_card_verification_code end |
#allow_deep_web_urls ⇒ Object
Set to true to allow deep web URLs (.onion) in the input text and not flag them as PII.
79 80 81 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 79 def allow_deep_web_urls @allow_deep_web_urls end |
#allow_drivers_license ⇒ Object
Set to true to allow drivers license numbers in the input text and not flag them as PII.
40 41 42 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 40 def allow_drivers_license @allow_drivers_license end |
#allow_email_address ⇒ Object
Set to true to allow email addresses in the input text and not flag them as PII.
22 23 24 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 22 def allow_email_address @allow_email_address end |
#allow_health_insurance_number ⇒ Object
Set to true to allow health insurance numbers in the input text and not flag them as PII.
64 65 66 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 64 def allow_health_insurance_number @allow_health_insurance_number end |
#allow_http_cookie ⇒ Object
Set to true to allow HTTP cookies in the input text and not flag them as PII.
70 71 72 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 70 def @allow_http_cookie end |
#allow_iban ⇒ Object
Set to true to allow IBANs in the input text and not flag them as PII.
61 62 63 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 61 def allow_iban @allow_iban end |
#allow_ip_address ⇒ Object
Set to true to allow IP addresses in the input text and not flag them as PII.
85 86 87 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 85 def allow_ip_address @allow_ip_address end |
#allow_mac_address ⇒ Object
Set to true to allow MAC addresses in the input text and not flag them as PII.
88 89 90 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 88 def allow_mac_address @allow_mac_address end |
#allow_passport_number ⇒ Object
Set to true to allow passport numbers in the input text and not flag them as PII.
37 38 39 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 37 def allow_passport_number @allow_passport_number end |
#allow_person_name ⇒ Object
Set to true to allow person names in the input text and not flag them as PII.
31 32 33 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 31 def allow_person_name @allow_person_name end |
#allow_phone_number ⇒ Object
Set to true to allow phone numbers in the input text and not flag them as PII.
25 26 27 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 25 def allow_phone_number @allow_phone_number end |
#allow_private_keys ⇒ Object
Set to true to allow private keys in the input text and not flag them as PII.
73 74 75 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 73 def allow_private_keys @allow_private_keys end |
#allow_social_security_number ⇒ Object
Set to true to allow social security numbers in the input text and not flag them as PII.
43 44 45 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 43 def @allow_social_security_number end |
#allow_source_code ⇒ Object
Set to true to allow source code in the input text and not flag it as sensitive data.
82 83 84 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 82 def allow_source_code @allow_source_code end |
#allow_street_address ⇒ Object
Set to true to allow street addresses in the input text and not flag them as PII.
28 29 30 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 28 def allow_street_address @allow_street_address end |
#allow_taxpayer_id ⇒ Object
Set to true to allow taxpayer IDs in the input text and not flag them as PII.
46 47 48 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 46 def allow_taxpayer_id @allow_taxpayer_id end |
#input_text ⇒ Object
Text to scan for PII and sensitive data.
19 20 21 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 19 def input_text @input_text end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 91 def self.attribute_map { :'input_text' => :'InputText', :'allow_email_address' => :'AllowEmailAddress', :'allow_phone_number' => :'AllowPhoneNumber', :'allow_street_address' => :'AllowStreetAddress', :'allow_person_name' => :'AllowPersonName', :'allow_birth_date' => :'AllowBirthDate', :'allow_passport_number' => :'AllowPassportNumber', :'allow_drivers_license' => :'AllowDriversLicense', :'allow_social_security_number' => :'AllowSocialSecurityNumber', :'allow_taxpayer_id' => :'AllowTaxpayerID', :'allow_credit_card_number' => :'AllowCreditCardNumber', :'allow_credit_card_expiration_date' => :'AllowCreditCardExpirationDate', :'allow_credit_card_verification_code' => :'AllowCreditCardVerificationCode', :'allow_bank_account_number' => :'AllowBankAccountNumber', :'allow_iban' => :'AllowIBAN', :'allow_health_insurance_number' => :'AllowHealthInsuranceNumber', :'allow_bearer_token' => :'AllowBearerToken', :'allow_http_cookie' => :'AllowHttpCookie', :'allow_private_keys' => :'AllowPrivateKeys', :'allow_credentials' => :'AllowCredentials', :'allow_deep_web_urls' => :'AllowDeepWebUrls', :'allow_source_code' => :'AllowSourceCode', :'allow_ip_address' => :'AllowIpAddress', :'allow_mac_address' => :'AllowMacAddress' } end |
.swagger_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 121 def self.swagger_types { :'input_text' => :'String', :'allow_email_address' => :'BOOLEAN', :'allow_phone_number' => :'BOOLEAN', :'allow_street_address' => :'BOOLEAN', :'allow_person_name' => :'BOOLEAN', :'allow_birth_date' => :'BOOLEAN', :'allow_passport_number' => :'BOOLEAN', :'allow_drivers_license' => :'BOOLEAN', :'allow_social_security_number' => :'BOOLEAN', :'allow_taxpayer_id' => :'BOOLEAN', :'allow_credit_card_number' => :'BOOLEAN', :'allow_credit_card_expiration_date' => :'BOOLEAN', :'allow_credit_card_verification_code' => :'BOOLEAN', :'allow_bank_account_number' => :'BOOLEAN', :'allow_iban' => :'BOOLEAN', :'allow_health_insurance_number' => :'BOOLEAN', :'allow_bearer_token' => :'BOOLEAN', :'allow_http_cookie' => :'BOOLEAN', :'allow_private_keys' => :'BOOLEAN', :'allow_credentials' => :'BOOLEAN', :'allow_deep_web_urls' => :'BOOLEAN', :'allow_source_code' => :'BOOLEAN', :'allow_ip_address' => :'BOOLEAN', :'allow_mac_address' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 270 def ==(o) return true if self.equal?(o) self.class == o.class && input_text == o.input_text && allow_email_address == o.allow_email_address && allow_phone_number == o.allow_phone_number && allow_street_address == o.allow_street_address && allow_person_name == o.allow_person_name && allow_birth_date == o.allow_birth_date && allow_passport_number == o.allow_passport_number && allow_drivers_license == o.allow_drivers_license && == o. && allow_taxpayer_id == o.allow_taxpayer_id && allow_credit_card_number == o.allow_credit_card_number && allow_credit_card_expiration_date == o.allow_credit_card_expiration_date && allow_credit_card_verification_code == o.allow_credit_card_verification_code && allow_bank_account_number == o.allow_bank_account_number && allow_iban == o.allow_iban && allow_health_insurance_number == o.allow_health_insurance_number && allow_bearer_token == o.allow_bearer_token && == o. && allow_private_keys == o.allow_private_keys && allow_credentials == o.allow_credentials && allow_deep_web_urls == o.allow_deep_web_urls && allow_source_code == o.allow_source_code && allow_ip_address == o.allow_ip_address && allow_mac_address == o.allow_mac_address end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 335 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudmersiveDlpApiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 401 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 314 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
301 302 303 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 301 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 307 def hash [input_text, allow_email_address, allow_phone_number, allow_street_address, allow_person_name, allow_birth_date, allow_passport_number, allow_drivers_license, , allow_taxpayer_id, allow_credit_card_number, allow_credit_card_expiration_date, allow_credit_card_verification_code, allow_bank_account_number, allow_iban, allow_health_insurance_number, allow_bearer_token, , allow_private_keys, allow_credentials, allow_deep_web_urls, allow_source_code, allow_ip_address, allow_mac_address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
257 258 259 260 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 257 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
381 382 383 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 381 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
375 376 377 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 375 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 |
# File 'lib/cloudmersive-dlp-api-client/models/dlp_detection_request.rb', line 264 def valid? true end |