Class: CloudmersiveDlpApiClient::TasksBatchJobApi
- Inherits:
-
Object
- Object
- CloudmersiveDlpApiClient::TasksBatchJobApi
- Defined in:
- lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#detect_audio_advanced_batch_job(opts = {}) ⇒ DlpBatchJobResult
Detect User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for detecting user data in an audio file using Advanced detection.
-
#detect_audio_advanced_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Detect User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for detecting user data in an audio file using Advanced detection.
-
#detect_audio_batch_job(opts = {}) ⇒ DlpBatchJobResult
Detect User Data in Audio File as a Batch Job Creates an async batch job for detecting user data in an audio file.
-
#detect_audio_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Detect User Data in Audio File as a Batch Job Creates an async batch job for detecting user data in an audio file.
-
#get_async_job_status(opts = {}) ⇒ DlpBatchJobStatusResult
Get the status and result of a DLP Batch Job Returns the result of the Async Job - possible states can be STARTED or COMPLETED.
-
#get_async_job_status_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobStatusResult, Fixnum, Hash)>
Get the status and result of a DLP Batch Job Returns the result of the Async Job - possible states can be STARTED or COMPLETED.
-
#initialize(api_client = ApiClient.default) ⇒ TasksBatchJobApi
constructor
A new instance of TasksBatchJobApi.
-
#redact_audio_advanced_batch_job(opts = {}) ⇒ DlpBatchJobResult
Redact User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for redacting user data in an audio file using Advanced detection.
-
#redact_audio_advanced_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Redact User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for redacting user data in an audio file using Advanced detection.
-
#redact_audio_batch_job(opts = {}) ⇒ DlpBatchJobResult
Redact User Data in Audio File as a Batch Job Creates an async batch job for redacting user data in an audio file.
-
#redact_audio_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Redact User Data in Audio File as a Batch Job Creates an async batch job for redacting user data in an audio file.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TasksBatchJobApi
Returns a new instance of TasksBatchJobApi.
19 20 21 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#detect_audio_advanced_batch_job(opts = {}) ⇒ DlpBatchJobResult
Detect User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for detecting user data in an audio file using Advanced detection. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the result when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA) and detects 29 configurable types of user data including health-related PHI in the transcript using Advanced AI. Returns the full transcript, token timestamps, detection results, and optional rationale. Requires Managed Instance or Private Cloud deployment.
27 28 29 30 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 27 def detect_audio_advanced_batch_job(opts = {}) data, _status_code, _headers = detect_audio_advanced_batch_job_with_http_info(opts) data end |
#detect_audio_advanced_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Detect User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for detecting user data in an audio file using Advanced detection. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the result when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA) and detects 29 configurable types of user data including health-related PHI in the transcript using Advanced AI. Returns the full transcript, token timestamps, detection results, and optional rationale. Requires Managed Instance or Private Cloud deployment.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 37 def detect_audio_advanced_batch_job_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksBatchJobApi.detect_audio_advanced_batch_job ...' end # resource path local_var_path = '/dlp/batch-job/detect/audio/advanced' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpBatchJobResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksBatchJobApi#detect_audio_advanced_batch_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#detect_audio_batch_job(opts = {}) ⇒ DlpBatchJobResult
Detect User Data in Audio File as a Batch Job Creates an async batch job for detecting user data in an audio file. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the result when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA) and detects 23 configurable types of user data in the transcript using Advanced AI. Returns the full transcript, token timestamps, and detection results. Requires Managed Instance or Private Cloud deployment.
77 78 79 80 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 77 def detect_audio_batch_job(opts = {}) data, _status_code, _headers = detect_audio_batch_job_with_http_info(opts) data end |
#detect_audio_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Detect User Data in Audio File as a Batch Job Creates an async batch job for detecting user data in an audio file. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the result when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA) and detects 23 configurable types of user data in the transcript using Advanced AI. Returns the full transcript, token timestamps, and detection results. Requires Managed Instance or Private Cloud deployment.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 87 def detect_audio_batch_job_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksBatchJobApi.detect_audio_batch_job ...' end # resource path local_var_path = '/dlp/batch-job/detect/audio' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpBatchJobResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksBatchJobApi#detect_audio_batch_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_async_job_status(opts = {}) ⇒ DlpBatchJobStatusResult
Get the status and result of a DLP Batch Job Returns the result of the Async Job - possible states can be STARTED or COMPLETED. When COMPLETED, the corresponding result field (detection or redaction result) is populated on the response. This API is only available for Cloudmersive Managed Instance and Private Cloud deployments.
127 128 129 130 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 127 def get_async_job_status(opts = {}) data, _status_code, _headers = get_async_job_status_with_http_info(opts) data end |
#get_async_job_status_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobStatusResult, Fixnum, Hash)>
Get the status and result of a DLP Batch Job Returns the result of the Async Job - possible states can be STARTED or COMPLETED. When COMPLETED, the corresponding result field (detection or redaction result) is populated on the response. This API is only available for Cloudmersive Managed Instance and Private Cloud deployments.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 137 def get_async_job_status_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksBatchJobApi.get_async_job_status ...' end # resource path local_var_path = '/dlp/batch-job/status' # query parameters query_params = {} query_params[:'AsyncJobID'] = opts[:'async_job_id'] if !opts[:'async_job_id'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpBatchJobStatusResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksBatchJobApi#get_async_job_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_audio_advanced_batch_job(opts = {}) ⇒ DlpBatchJobResult
Redact User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for redacting user data in an audio file using Advanced detection. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the redacted audio and transcript when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, redacted segment timestamps, and optional rationale. Requires Managed Instance or Private Cloud deployment.
176 177 178 179 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 176 def redact_audio_advanced_batch_job(opts = {}) data, _status_code, _headers = redact_audio_advanced_batch_job_with_http_info(opts) data end |
#redact_audio_advanced_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Redact User Data in Audio File (Advanced) as a Batch Job Creates an async batch job for redacting user data in an audio file using Advanced detection. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the redacted audio and transcript when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 34 configurable types of user data including health-related PHI in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, redacted segment timestamps, and optional rationale. Requires Managed Instance or Private Cloud deployment.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 186 def redact_audio_advanced_batch_job_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksBatchJobApi.redact_audio_advanced_batch_job ...' end # resource path local_var_path = '/dlp/batch-job/redact/audio/advanced' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpBatchJobResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksBatchJobApi#redact_audio_advanced_batch_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#redact_audio_batch_job(opts = {}) ⇒ DlpBatchJobResult
Redact User Data in Audio File as a Batch Job Creates an async batch job for redacting user data in an audio file. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the redacted audio and transcript when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, and redacted segment timestamps. Requires Managed Instance or Private Cloud deployment.
226 227 228 229 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 226 def redact_audio_batch_job(opts = {}) data, _status_code, _headers = redact_audio_batch_job_with_http_info(opts) data end |
#redact_audio_batch_job_with_http_info(opts = {}) ⇒ Array<(DlpBatchJobResult, Fixnum, Hash)>
Redact User Data in Audio File as a Batch Job Creates an async batch job for redacting user data in an audio file. Use the GetAsyncJobStatus API to check on the status of the job and retrieve the redacted audio and transcript when complete. Transcribes an audio file (WAV, MP3, M4A, FLAC, OGG, WMA), detects 23 configurable types of user data in the transcript, and redacts audio segments containing PII. Returns the redacted audio, redacted transcript, detection results, and redacted segment timestamps. Requires Managed Instance or Private Cloud deployment.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/cloudmersive-dlp-api-client/api/tasks_batch_job_api.rb', line 236 def redact_audio_batch_job_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksBatchJobApi.redact_audio_batch_job ...' end # resource path local_var_path = '/dlp/batch-job/redact/audio' # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['Apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DlpBatchJobResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksBatchJobApi#redact_audio_batch_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |